﻿# PROGRAMME TERMINALE SPECIALITE 2021
# -----------------------------------
# code proposé par Olivier CHAUMETTE - Lycée JPS Sartre - 69600 BRON
# -------------------------------------------------
# Programme Python permettant de tracer les positions d'un point M
# à partir d'abscisses et d'ordonnées issues d'un pointage (ou d'équations).
# de déterminer Vx,Vy,ax et ay
# et de tracer sur plusieurs figures les évolutions temporelles
# -----------------------------------------------------------


# ##########################
# IMPORTATION DES MODULES #
# #########################
import numpy as np
import matplotlib.pyplot as plt

# modules permettant d'importer des données
# LE FICHIER "import_donnees2.py" EST INDISPENSABLE
# (version 2 avec bonnes équations horaires)
from import_donnees_meca2 import traiteDonnees


""" ---------------------------------
        CHOIX du PROFESSEUR
------------------------------------- """
#  Logiciel utilisé à choisir parmi :
# 'pymecavideo'     (exporter un fichier TXT)
# 'latispro'        (fichier TXT créé par LATISPRO, avec décimale VIRGULE et séparation POINT VIRGULE)
# 'avimeca'         (crééer un fichier TXT en export)
# 'avistep'         (pointage exporté depuis AVISTEP:
# 'equation'        (équation paramétrées saisies dans le fichier "import_donnees2")
# 'entrees'        (données de pointage saisies "à la main" dans le fichier "import_donnees2.py)

Logiciel_Utilise = 'latispro'

""" ---------------------------------
        FIN du CHOIX du PROFESSEUR
------------------------------------- """

# Initialisation des tableaux numpy contenant x,y,t et les coordonnées des vitesses
x=np.array([])
y=np.array([])
t=np.array([])

# appel au module permettant d'importer les données pointées (récupérées dans x,y et t)
t, x, y = traiteDonnees(Logiciel_Utilise)
# nombre de mesures
Nbre_Mesures=len(x)

# ASTUCE (discutable !) pour avoir une correspondance entre le n° du point et l'index des tableau numpy des coordonnées de V:
# Comme on va construire un tableau numpy de vitesses (qui est vide au départ) et que
# la première V que l'on peut calculer est celle du point n°1 (à cause de la méthode centrée),
# la vitesse du point n°1 correspondra à l'index 0 du tableau numpy de vitesses (car un tableau commence à 0).
# Mais dire que "V du point 1 correspond à V[0]" est problématique pour les élèves.
# D'où l'idée de mettre une vitesse à l'index 0 du tableau et ainsi, la 1ère vitesse calculée par les élèves (celle du point 1)
# va être ajoutée au tableau de vitesse et se retrouver à l'index 1. La vitesse du point 1 sera V[1]

# Pour évaluer la vitesse à t=0, on utilise la méthode de la dérivée numérique à droite
# (moins bonne que la dérivée centrée mais on n'a pas le choix)
# Ceci n'est pas à dire aux élèves !

# calcul de Vox et Voy avec la méthode de la dérivée numérique à droite.
Vox=(x[1]-x[0])/(t[1]-t[0])
Voy=(y[1]-y[0])/(t[1]-t[0])
# on créé les listes Vx et Vy (et V) avec 1 seul élément pour l'instant: V0
Vx=np.array([Vox])
Vy=np.array([Voy])
V=np.array([np.sqrt(Voy*Voy+Vox*Vox)])


""" ###########################################
Ici commence le travail à réaliser par les élèves
################################################# """

# #####################################
# Calcul des coordonnées des Vecteurs vitesse
# #####################################
""" TRAVAIL 1:
Taper, DANS LA BOUCLE ci-dessous, le code python permettant:
    - de calculer Vxn (abscisse du vecteur vitesse au point numéro "n")
    - d'ajouter Vxn au tableau Vx
    - de calculer Vyn (ordonnée du vecteur vitesse au point numéro "n")
    - d'ajouter Vyn au tableau Vy
    - de calculer Vn (norme du vecteur vitesse au point numéro "n")
    - d'ajouter Vn au tableau V      """

for n in range (1,Nbre_Mesures-1):




# obligation de rajouter 1 valeur aux vitesses pour que tous les tableaux aient le même nombre d'éléments (sinon, tracé trop complexe pour les élèves)
# arbitrairement, on met l'avant dernière valeur calculée. Il faut que les élèves soient conscients que la dernière valeur de vitesse (et la 1ère) n'ont aucun sens.
V=np.append(V,np.sqrt(Vx[-1]**2+Vy[-1]**2))
Vx=np.append(Vx,Vx[-1])
Vy=np.append(Vy,Vy[-1])

# ##################################
# Calcul des énergies              #
# ##################################
""" TRAVAIL 2:
Taper ci-dessous le code python permettant:
    - de mettre les valeurs de m et de g dans 2 variables
    - de calculer Ec
    - de calculer Epp
    - de calculer Em    """



# #####################################
# Tracé des énergies en fonction de t #
# #####################################
""" TRAVAIL 3:
Taper ci-dessous le code python permettant:
    - de tracer Ec en fonction de t en croix rouge avec comme label: Ec(t)
    - Faire de même pour Epp et Em avec des couleurs différentes
    - Compléter le titre et le nom des axes """



plt.title(".....................................")          # titre du graphique
plt.xlabel(".....................................")                  # nom de la grandeur sur l'axe X
plt.ylabel(".....................................")             # nom de la grandeur sur l'axe Y


plt.grid()
plt.legend()          # pour afficher les "label" des plot


""" ###########################################
           FIN du travail
################################################# """


# on affiche la fenêtre
#plt.get_current_fig_manager().window.state('zoomed')   # <-- Affiche la fenêtre maximisée sous windows uniquement
plt.show()
